from django.shortcuts import render, redirect
from django.contrib.auth import login
from django.contrib.auth.decorators import login_required
from .forms import SignUpForm, UserProfileForm
from .models import UserProfile
from django.core.mail import send_mail, BadHeaderError
from django.http import HttpResponse
from django.contrib.auth.forms import PasswordResetForm
from django.contrib.auth.models import User
from django.template.loader import render_to_string
from django.db.models.query_utils import Q
from django.contrib.auth.tokens import default_token_generator
from django.utils.http import urlsafe_base64_encode
from django.utils.encoding import force_bytes

def signup(request):
    if request.method == 'POST':
        form = SignUpForm(request.POST)
        if form.is_valid():
            user = form.save()
            login(request, user)
            profile=UserProfile(profile_user=user)
            profile.profile_pic='images/user-default.png'
            profile.save()
            return redirect('setup_profile')
    else:
        form = SignUpForm()
    return render(request, 'accounts/signup.html', {'form': form})

@login_required
def setup_profile(request):
    profile=UserProfile.objects.get(profile_user=request.user)
    if request.method == 'POST':
        form = UserProfileForm(request.POST, request.FILES,instance=profile)
        if form.is_valid():
            profile = form.save(commit=False)
            profile.save()
            return redirect('feed')
    else:
        form = UserProfileForm()
    return render(request, 'accounts/setup_profile.html', {'form': form})

"""@login_required
def change_password(request):
    return render(request, 'accounts/change_password.html')

 def resetPassword(request):
    return render(request, 'accounts/reset_password.html')

def setNewPasswordFromReset(request):
    return render(request, 'accounts/reset_password_set_new_password.html')

def announceCompletedPasswordReset(request):
    return render(request, 'accounts/reset_password_completed.html')

def changePassword(request):
    return render(request, 'accounts/change_password.html')

def announceCompletedPasswordChange(request):
    return render(request, 'accounts/change_password_completed.html') """

def password_reset_request(request):
	if request.method == "POST":
		password_reset_form = PasswordResetForm(request.POST)
		if password_reset_form.is_valid():
			data = password_reset_form.cleaned_data['email']
			associated_users = User.objects.filter(Q(email=data))
			if associated_users.exists():
				for user in associated_users:
					subject = "Password Reset Requested"
					email_template_name = "accounts/password_reset_email.txt"
					c = {
                        "email":user.email,
                        'domain':'127.0.0.1:8000',
                        'site_name': 'SINTRA',
                        "uid": urlsafe_base64_encode(force_bytes(user.pk)),
                        "user": user,
                        'token': default_token_generator.make_token(user),
                        'protocol': 'http',
					}
					email = render_to_string(email_template_name, c)
					try:
						send_mail(subject, email, 'damian.luba@ysbf.org' , [user.email], fail_silently=False)
					except BadHeaderError:
						return HttpResponse('Invalid header found.')
					return redirect ("/password-reset_message-sent/")
	password_reset_form = PasswordResetForm()
	return render(request=request, template_name="accounts/password_reset.html", context={"password_reset_form":password_reset_form})