"""mysite URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from accounts import views as accounts_views
from ideabook import views as ideabook_views
from django.contrib.auth import views as auth_views
from django.views.generic.base import RedirectView
from django.contrib.staticfiles.storage import staticfiles_storage
from django.templatetags.static import static
from django.conf.urls.static import static
from django.conf import settings

urlpatterns = [
    path('admin/', admin.site.urls),
    path('favicon.ico', RedirectView.as_view(url=staticfiles_storage.url('images/favicon.ico'))),
    path('', ideabook_views.feedview, name='feed'),
    path('like-idea/<int:pk>/', ideabook_views.like_idea, name='like_idea'),
    path('like-sugg/<int:pk>/', ideabook_views.like_sugg, name='like_sugg'),
    path('<int:pk>/', ideabook_views.ideaview, name='idea'),
    path('user_account/<int:pk>', ideabook_views.useraccountview, name='user_account'),
    path('delete/<int:pk>/', ideabook_views.delete_idea, name='delete_idea'),
    path('edit_idea/<int:pk>/', ideabook_views.edit_idea, name='edit_idea'),
    path('search/', ideabook_views.searchview, name='search'),
    path('about-o-sintra/', ideabook_views.about, name='about'),
    path('follow/<int:pk>/', ideabook_views.follow, name='follow'),
    path('sign-up/', accounts_views.signup, name='signup'),
    path('setup_profile/', accounts_views.setup_profile, name='setup_profile'),
    path('login/', auth_views.LoginView.as_view(template_name='accounts/login.html'), name='login'),
    path('logout/', auth_views.LogoutView.as_view(), name='logout'),
    
    path('password-reset/', accounts_views.password_reset_request, name='password_reset'),
    path('password-reset_message-sent/', auth_views.PasswordResetDoneView.as_view(template_name='accounts/password_reset_message_sent.html'), name='password_reset_done'),
    path('password-reset_set-new-password/<uidb64>/<token>/', auth_views.PasswordResetConfirmView.as_view(template_name='accounts/password_reset_set_new_password.html'), name='password_reset_confirm'),
    path('password-reset_completed/', auth_views.PasswordResetCompleteView.as_view(template_name='accounts/password_reset_completed.html'), name='password_reset_complete'),
    
    path('change-password/', auth_views.PasswordChangeView.as_view(), name='password_change'),
    path('change-password_completed/', auth_views.PasswordChangeDoneView.as_view(), name='password_change_done'),
]
urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)